Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Broker ¶
type Broker struct {
// contains filtered or unexported fields
}
Broker handles batching of items for efficient processing
func (*Broker) Clear ¶ added in v0.0.2
func (b *Broker) Clear()
Clear cleans the queue without triggering a flush
func (*Broker) FlushNow ¶ added in v0.0.2
func (b *Broker) FlushNow()
FlushNow forces an immediate flush
func (*Broker) QueueLength ¶ added in v0.0.2
QueueLength returns the current number of unique keys in the queue
func (*Broker) SetOnFlush ¶ added in v0.0.2
SetOnFlush configures the callback for when the batch window expires
Click to show internal directories.
Click to hide internal directories.